SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

IF EXISTS (SELECT * FROM [dbo].[sysobjects]
           WHERE ID = object_id(N'[dbo].[ufnGetTransferSourceDestInfo]') AND
                 XTYPE IN (N'FN', N'IF', N'TF'))
    DROP FUNCTION [dbo].[ufnGetTransferSourceDestInfo]
GO

CREATE FUNCTION [dbo].[ufnGetTransferSourceDestInfo](@TransactionId NVARCHAR(50))
RETURNS 
@returnInformation TABLE 
(
	-- Add the column definitions for the TABLE variable here
	[InfoType] INT NOT NULL, 
	[SourceType] INT NULL, 
	[SourceFile] [NVARCHAR] (512) NULL,
	[SourceInfo] [NVARCHAR](512) NULL,
	[DestType] INT NULL,
    [DestFile] [NVARCHAR] (512) NULL,
	[DestInfo] NVARCHAR(512) NULL,
	[FileSupplemental] NTEXT NULL,
	[FileCount] INT NULL
)
AS
BEGIN
	-- Fill the table variable with the rows for your result set
	IF @TransactionId IS NULL RETURN
	IF (EXISTS(SELECT * FROM [TrnFTEFile] F WHERE F.TransactionId = @TransactionId))
	BEGIN
		INSERT INTO @returnInformation
			SELECT TOP 1 1, F.SourceType, F.SourceFile, F.SourceInfo, F.DestType, F.DestFile, F.DestInfo, F.Supplemental, (SELECT COUNT(*) FROM TrnFTEFile F WHERE F.TransactionId = @TransactionId) FROM TrnFTEFile F INNER JOIN TrnFTETransaction T ON T.TransactionId = F.TransactionId WHERE F.TransactionId = @TransactionId
	END ELSE
	BEGIN
		IF (EXISTS(SELECT * FROM [TrnFTECommand] C WHERE C.TransactionId = @TransactionId))
		BEGIN
			INSERT INTO @returnInformation
				SELECT TOP 1 2, NULL, C.CommandInfo,NULL, NULL, NULL, NULL, NULL, NULL FROM TrnFTECommand C INNER JOIN TrnFTETransaction T ON T.TransactionId = C.TransactionId WHERE C.TransactionId = @TransactionId
		END ELSE
		BEGIN
			INSERT INTO @returnInformation VALUES(3,NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL)
		END
	END
	RETURN 
END
GO

ALTER PROCEDURE [dbo].[DeleteFTEAS] 
--- Routine to delete an FTE Agent Status Record and all 
--- it's sub parts
	@Id INT,
	@AgentName NVARCHAR(50),
	@QueueManager NVARCHAR(50), 
	@LastUpdate DATETIME
AS
BEGIN
	SET NOCOUNT ON;
	BEGIN TRANSACTION
--- Delete Monitors
IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
                 AND  TABLE_NAME = 'TrnFTEMonitor'))
BEGIN

    UPDATE [TrnFTEMonitor] SET [Status] = 99 WHERE (MstFTEAgent_Id = @Id) 
    IF @@ERROR <> 0
	BEGIN
		ROLLBACK
		RAISERROR('Error Deleting FTE Agent Status Monitors',16,1)
	    RETURN
	END
END
IF (EXISTS (SELECT * 
                 FROM INFORMATION_SCHEMA.TABLES 
                 WHERE TABLE_SCHEMA = 'dbo' 
                 AND  TABLE_NAME = 'TrnFTESchedule'))
BEGIN
--- Delete Schedules
    UPDATE [TrnFTESchedule] SET [Status] = 99 WHERE (MstFTEAgent_SourceId = @Id OR MstFTEAgent_DestId = @Id) 
    IF @@ERROR <> 0
	BEGIN
		ROLLBACK
		RAISERROR('Error Deleting FTE Agent Schedule Monitors',16,1)
	    RETURN
	END
END--- Delete all Transactions
    DELETE FROM [TrnFTEASTransaction] WHERE [AgentName] = @AgentName AND [QueueManager] = @QueueManager
	IF @@ERROR <> 0
	BEGIN
		ROLLBACK
		RAISERROR('Error Deleting FTE Agent Status Transactions',16,1)
	    RETURN
	END
--- Delete all Properties
	DELETE FROM [TrnFTEASProperty] WHERE [AgentName] = @AgentName AND [QueueManager] = @QueueManager
	IF @@ERROR <> 0
	BEGIN
		ROLLBACK
		RAISERROR('Error Deleting FTE Agent Status Properties',16,1)
		RETURN
	END
--- Delete the Header
	UPDATE [TrnFTEAS] SET [Status] = 99, LastUpdate = @LastUpdate WHERE [AgentName] = @AgentName AND [QueueManager] = @QueueManager
	IF @@ERROR <> 0
	BEGIN
		ROLLBACK
		RAISERROR('Error Deleting FTE Agent Status Header',16,1)
		RETURN
	END
--- Commit
	COMMIT
END
GO

/****** Object:  UserDefinedFunction [dbo].[ufnGetTransferSourceDestInfo]    Script Date: 10/04/2013 11:53:40 ******/



INSERT INTO MstList
                         (ListType, ListCode, ListDesc, AddInfo)
VALUES        ('FTEMetaBaseKeyword', 'Supplemental', 'Supplemental', 
                         '<data><criteria type="0">T.[Supplemental]</criteria><criteria type="2">[Supplemental]</criteria></data>')
GO


